==> DSS-4.2.5.tar.gz: DSS-4.2.5/DeepSkyStackerLive/resource.h <==
﻿//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by DeepSkyStackerLive.rc
//
#define IDD_DEEPSKYSTACKERLIVE_DIALOG   102
#define IDD_DEEPSKYSTACKERLIVE          102
#define IDR_MAINFRAME                   128
#define IDD_EXPLORERBAR                 128
#define IDD_MAINBOARD                   128
#define IDB_HDRUP                       129
#define IDD_LOG                         129
#define IDD_IMAGEVIEW                   130
#define IDB_HDRDOWN                     131
#define IDD_IMAGELIST                   131
#define IDD_GRAPHS                      132
#define IDD_SETTINGS                    133
#define IDD_RESTARTMONITORING           134
#define IDD_EMAILSETTINGS               135
#define IDD_MAINBOARDMINI               136
#define IDB_BITMAP1                     136
#define IDB_4CORNERS                    136
#define IDS_COLUMN_PATH                 200
#define IDS_COLUMN_FILE                 201
#define IDS_COLUMN_TYPE                 202
#define IDS_COLUMN_SCORE                203
#define IDS_COLUMN_DX                   204
#define IDS_COLUMN_DY                   205
#define IDS_COLUMN_ANGLE                206
#define IDS_COLUMN_DATETIME             207
#define IDS_COLUMN_SIZES                208
#define IDS_COLUMN_CFA                  209
#define IDS_COLUMN_DEPTH                210
#define IDS_COLUMN_INFOS                211
#define IDS_COLUMN_ISO_GAIN             212
#define IDS_COLUMN_EXPOSURE             213
#define IDS_COLUMN_STARS                214
#define IDS_COLUMN_SKYBACKGROUND        215
#define IDS_COLUMN_APERTURE             216
#define IDS_FORMAT_RGB                  400
#define IDS_FORMAT_GRAY                 401
#define IDS_YES                         402
#define IDS_NO                          403
#define IDS_EXPOSUREFORMAT_SUP          404
#define IDS_EXPOSUREFORMAT_INF          405
#define IDS_EXPOSURE0                   500
#define IDS_EXPOSURE1                   501
#define IDS_EXPOSURE2                   502
#define IDS_EXPOSURE3                   503
#define IDS_EXPOSURETIME1               512
#define IDS_EXPOSURETIME2               513
#define IDS_EXPOSURETIME3               514
#define IDC_BUTTON1                     1000
#define IDC_START                       1000
#define IDC_APPLYCHANGES                1000
#define IDC_MONITOR                     1000
#define IDC_TEST                        1000
#define IDC_BUTTON2                     1001
#define IDC_LOG                         1001
#define IDC_CANCELCHANGES               1001
#define IDC_STACK                       1001
#define IDC_BUTTON3                     1002
#define IDC_PAUSE                       1002
#define IDC_PICTURE                     1002
#define IDC_MONITOR2                    1002
#define IDC_REDUCE                      1002
#define IDC_MONITORINGRECT              1003
#define IDC_MONITOREDFOLDER             1004
#define IDC_STOP                        1005
#define IDC_STACKEDIMAGE                1006
#define IDC_LASTIMAGE                   1007
#define IDC_GRAPHS                      1008
#define IDC_IMAGELIST                   1009
#define IDC_LOGLIST                     1010
#define IDC_WARNINGS                    1011
#define IDC_FILENAME                    1012
#define IDC_GRAPH                       1014
#define IDC_SCORE                       1015
#define IDC_FWHM                        1016
#define IDC_PROGRESS                    1016
#define IDC_STARS                       1017
#define IDC_DONTSTACK                   1017
#define IDC_DONTSTACK_SCORE             1018
#define IDC_DONTSTACK_STARS             1019
#define IDC_DONTSTACK_FWHM              1020
#define IDC_OFFSET                      1021
#define IDC_STARCOUNT                   1022
#define IDC_ANGLE                       1023
#define IDC_DONTSTACK_OFFSET            1024
#define IDC_SKYBACKGROUND               1024
#define IDC_EDIT4                       1025
#define IDC_MINIMAGES                   1025
#define IDC_DONTSTACK_ANGLE             1026
#define IDC_EDIT5                       1027
#define IDC_DONTSTACK_SKYBACKGROUND     1027
#define IDC_WARN_SOUND                  1028
#define IDC_WARN_FLASH                  1029
#define IDC_WARN_SCORE                  1030
#define IDC_WARN_STARS                  1031
#define IDC_WARN_FWHM                   1032
#define IDC_WARN_OFFSET                 1033
#define IDC_WARN_ANGLE                  1034
#define IDC_SAVESTACKEDIMAGE            1035
#define IDC_EDIT6                       1036
#define IDC_IMAGECOUNT                  1036
#define IDC_WARN_EMAIL                  1037
#define IDC_WARN_FILE                   1038
#define IDC_STACKEDOUTPUTFOLDER         1039
#define IDC_STACKING                    1040
#define IDC_OPTIONS                     1041
#define IDC_STATS                       1042
#define IDC_WARNINGFILEFOLDER           1042
#define IDC_WARN_SKYBACKGROUND          1043
#define IDC_MAX_SKYBACKGROUND           1044
#define IDC_DARKTHEME                   1045
#define IDC_SENDTO                      1048
#define IDC_SMTPSERVER                  1049
#define IDC_ACCOUNT                     1050
#define IDC_OBJECT                      1051
#define IDC_SENDONCE                    1052
#define IDC_EMAIL                       1053
#define IDC_RESETEMAILCOUNT             1054
#define IDC_STARTFROMCURRENTSTACKEDIMAGE 1055
#define IDC_CREATENEWSTACKEDIMAGE       1056
#define IDC_USEPENDINGIMAGES            1057
#define IDC_DROPPENDINGIMAGES           1058
#define IDC_PROCESS_RAW                 1059
#define IDC_PROCESS_FITS                1060
#define IDC_PROCESS_TIFF                1061
#define IDC_PROCESS_OTHERS              1062
#define IDC_FILTERS                     1063
#define IDC_MOVENONSTACKABLE            1064
#define IDC_COPYTOCLIPBOARD             1065
#define IDC_BACKGROUND                  1066
#define IDS_CREATEMASTERDARK            1100
#define IDS_CREATEMASTEROFFSET          1101
#define IDS_ADDOFFSET                   1102
#define IDS_ADDDARK                     1103
#define IDS_SAVINGMASTEROFFSET          1104
#define IDS_SAVINGMASTERDARK            1105
#define IDS_CREATEMASTERFLAT            1106
#define IDS_ADDFLAT                     1107
#define IDS_SAVINGMASTERFLAT            1108
#define IDS_CREATEMASTERDARKFLAT        1109
#define IDS_ADDDARKFLAT                 1110
#define IDS_SAVINGMASTERDARKFLAT        1111
#define IDS_ADDOFFSET2                  1112
#define IDS_REGISTERING                 1120
#define IDS_REGISTERINGPICTURE          1121
#define IDS_REGISTERINGNAME             1122
#define IDS_REGISTERINGNAMEPLUSTARS     1123
#define IDS_COMPUTINGLUMINANCE          1124
#define IDS_LOADRGBPICTURE              1125
#define IDS_LOADGRAYPICTURE             1126
#define IDS_LOADRGBDARK                 1127
#define IDS_LOADGRAYDARK                1128
#define IDS_ADDRGBDARK                  1129
#define IDS_ADDGRAYDARK                 1130
#define IDS_LOADRGBOFFSET               1131
#define IDS_LOADGRAYOFFSET              1132
#define IDS_ADDRGBOFFSET                1133
#define IDS_ADDGRAYOFFSET               1134
#define IDS_COMPUTINGOFFSETS            1135
#define IDS_COMPUTINGSTACKINGINFO       1136
#define IDS_STACKING                    1138
#define IDS_STACKING_PICTURE            1139
#define IDS_LOADRGBLIGHT                1140
#define IDS_LOADGRAYLIGHT               1141
#define IDS_STACKRGBLIGHT               1142
#define IDS_STACKGRAYLIGHT              1143
#define IDS_STACKING_COMPUTINGADJUSTMENT 1144
#define IDS_COMPUTINGADJUSTMENT         1145
#define IDS_STACKING_APPLYINGADJUSTMENT 1146
#define IDS_STACKING_COMPUTEMAXADJUSTMENT 1147
#define IDS_STACKING_APPLYADJUSTMENT    1148
#define IDS_COMPUTINGMEDIANOFFSET       1149
#define IDS_COMPUTINGMEDIANDARK         1150
#define IDS_COMPUTINGMEDIANFLAT         1151
#define IDS_LOADRGBFLAT                 1152
#define IDS_LOADGRAYFLAT                1153
#define IDS_ADDRGBFLAT                  1154
#define IDS_ADDGRAYFLAT                 1155
#define IDS_MEDIANDARKINFO              1156
#define IDS_MEDIANOFFSETINFO            1157
#define IDS_MEDIANFLATINFO              1158
#define IDS_SUBSTRACTINGOFFSET          1159
#define IDS_SUBSTRACTINGDARK            1160
#define IDS_APPLYINGFLAT                1161
#define IDS_NORMALIZINGMASTERFLAT       1162
#define IDC_GAMMA                       1162
#define IDS_COMPUTINGMINLUMINANCE       1163
#define IDS_COMPUTINGENTROPY            1164
#define IDS_COMPUTINGBACKGROUNDCALIBRATION 1165
#define IDS_COMPUTINGDARKOPTIMIZATIONFACTOR 1166
#define IDS_REMOVINGHOTPIXELS           1167
#define IDS_DETECTINGHOTPIXELS1         1168
#define IDS_DETECTINGHOTPIXELS2         1169
#define IDS_COMPUTINGFLATCALIBRATION    1170
#define IDS_APPLYINGFLATCALIBRATION     1171
#define IDS_AHDDEMOSAICING              1172
#define IDS_PROCESSINGIMAGE             1173
#define IDS_APPLYINGCOSMETIC_HOT        1176
#define IDS_APPLYINGCOSMETIC_COLD       1177
#define IDS_CREATINGMEDIANIMAGE         1178
#define IDS_OPTIMIZINGDARKMATCHING      1179
#define IDS_LOADRGBDARKFLAT             1180
#define IDS_LOADGRAYDARKFLAT            1181
#define IDS_COMPUTINGMEDIANDARKFLAT     1182
#define IDS_MEDIANDARKFLATINFO          1183
#define IDS_COMPUTINGCOSMETICSTATS      1185
#define IDS_LOADDSIMAGE                 1200
#define IDS_LOADPICTURE                 1201
#define IDS_SAVEDSIMAGE                 1202
#define IDS_SAVINGDSIMAGE               1203
#define IDS_SAVINGTIFF                  1204
#define IDS_SAVINGPICTURE               1205
#define IDS_SAVEWITHSETTINGSAPPLIED     1206
#define IDS_SAVEWITHSETTINGSEMBEDDED    1207
#define IDS_LOADRGBTIFF                 1208
#define IDS_LOADGRAYTIFF                1209
#define IDS_DEEPSKYSTACKER              1210
#define IDS_SAVINGINTERMEDIATE          1211
#define IDS_SAVINGCALIBRATED            1213
#define IDS_LOADRGBFITS                 1215
#define IDS_LOADGRAYFITS                1216
#define IDS_SAVINGFITS                  1217
#define IDC_4CORNERS                    1258
#define IDS_COMPUTINGMEDIANLIGHT        1300
#define IDS_HAT_LINEAR                  2100
#define IDS_HAT_CUBEROOT                2101
#define IDS_HAT_SQUAREROOT              2102
#define IDS_HAT_LOG                     2103
#define IDS_HAT_LOGLOG                  2104
#define IDS_HAT_LOGSQUAREROOT           2105
#define IDS_HAT_ASINH                   2106
#define IDS_WANTTOCONTINUE              3004
#define IDS_RECAP_AVERAGE               4050
#define IDS_RECAP_MEDIAN                4051
#define IDS_RECAP_MAXIMUM               4052
#define IDS_RECAP_KAPPASIGMA            4053
#define IDS_RECAP_AUTOADAPTIVE          4054
#define IDS_RECAP_ENTROPYAVERAGE        4055
#define IDS_RECAP_MEDIANSIGMACLIP       4056
#define IDS_RECAP_MEGABYTES             4200
#define IDS_RECAP_KILOBYTES             4201
#define IDS_RECAP_GIGABYTES             4202
#define IDS_RECAP_WARNINGDISKSPACE      4250
#define IDS_CAMERA_NOT_SUPPORTED        8001
#define IDS_8BIT_FITS_NODEBAYER         8002
#define IDS_HELPFILE                    20000
#define IDS_SELECTMONITOREDFOLDER       42000
#define IDS_LOG_NEWFILESFOUND           42001
#define IDS_LOG_NEWFILE                 42002
#define IDS_LOG_STARTMONITORING         42003
#define IDS_LOG_PAUSEMONITORING         42004
#define IDS_LOG_STOPMONITORING          42005
#define IDS_LOG_ERRORSTARTMONITORING    42006
#define IDS_NOIMAGELOADED               42007
#define IDS_NOSTACKEDIMAGE              42008
#define IDS_LOG_REGISTERRESULTS         42009
#define IDS_LOG_STARTSTACKING           42010
#define IDS_LOG_STOPSTACKING            42011
#define IDS_LOG_STARTING                42012
#define IDS_LOG_STARTING_1              42013
#define IDS_LOG_STARTING_2              42014
#define IDS_LOG_STARTING_3              42015
#define IDS_LOG_STARTING_4              42016
#define IDS_LOG_STARTING_5              42017
#define IDSTR_LOG_ERRORLOADINGFILE      42018
#define IDS_LOG_ERRORLOADINGFILE        42018
#define IDS_STATUS_LOADED               42019
#define IDS_STATUS_REGISTERED           42020
#define IDS_STATUS_STACKDELAYED         42021
#define IDS_STATUS_NOTSTACKABLE         42022
#define IDS_STATUS_STACKED              42023
#define IDS_LOG_IMAGENOTSTACKABLE1      42024
#define IDS_NOSTACK_SCORE               42025
#define IDS_NOSTACK_STARS               42026
#define IDS_NOSTACK_FWHM                42027
#define IDS_NOSTACK_OFFSET              42028
#define IDS_NOSTACK_ANGLE               42029
#define IDS_NOSTACK_NOTRANSFORMATION    42030
#define IDS_LOG_WARNING                 42031
#define IDS_SELECTWARNINGFOLDER         42032
#define IDS_SELECTSTACKEDFOLDER         42033
#define IDS_SAVINGSTACKEDIMAGE          42034
#define IDS_ERRORSENDINGEMAIL           42035
#define IDS_EMAILSENTOK                 42036
#define IDS_CANTCHANGEMONITOREDFOLDER   42037
#define IDS_SAVESTACKEDIMAGE            42038
#define IDS_NOSTACKEDIMAGEFOLDER        42039
#define IDS_STACKEDIMAGEWILLBESAVED     42040
#define IDS_STACKEDIMAGESAVED           42041
#define IDS_USEEXISTINGIMAGES           42042
#define IDS_ERRORMOVINGFILE             42043
#define IDS_FILEMOVED                   42044
#define IDS_NOSTACK_SKYBACKGROUND       42045

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        140
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1067
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> DSS-5.1.5.tar.gz: DSS-5.1.5/DeepSkyStackerLive/resource.h <==
﻿//{{NO_DEPENDENCIES}}
// Microsoft Visual C++ generated include file.
// Used by DeepSkyStackerLive.rc
//
#define IDD_DEEPSKYSTACKERLIVE_DIALOG   102
#define IDD_DEEPSKYSTACKERLIVE          102
#define IDR_MAINFRAME                   128
#define IDD_EXPLORERBAR                 128
#define IDD_MAINBOARD                   128
#define IDB_HDRUP                       129
#define IDD_LOG                         129
#define IDD_IMAGEVIEW                   130
#define IDB_HDRDOWN                     131
#define IDD_IMAGELIST                   131
#define IDD_GRAPHS                      132
#define IDD_SETTINGS_LIVE               133
#define IDD_RESTARTMONITORING           134
#define IDD_EMAILSETTINGS               135
#define IDD_MAINBOARDMINI               136
//#define IDB_BITMAP1                     136
#define IDB_4CORNERS                    136
#define IDS_COLUMN_PATH                 200
#define IDS_COLUMN_FILE                 201
#define IDS_COLUMN_TYPE                 202
#define IDS_COLUMN_SCORE                203
#define IDS_COLUMN_DX                   204
#define IDS_COLUMN_DY                   205
#define IDS_COLUMN_ANGLE                206
#define IDS_COLUMN_DATETIME             207
#define IDS_COLUMN_SIZES                208
#define IDS_COLUMN_CFA                  209
#define IDS_COLUMN_DEPTH                210
#define IDS_COLUMN_INFOS                211
#define IDS_COLUMN_ISO_GAIN             212
#define IDS_COLUMN_EXPOSURE             213
#define IDS_COLUMN_STARS                214
#define IDS_COLUMN_SKYBACKGROUND        215
#define IDS_COLUMN_APERTURE             216
#define IDS_FORMAT_RGB                  400
#define IDS_FORMAT_GRAY                 401
#define IDS_YES                         402
#define IDS_NO                          403
#define IDS_EXPOSUREFORMAT_SUP          404
#define IDS_EXPOSUREFORMAT_INF          405
#define IDS_EXPOSURE0                   500
#define IDS_EXPOSURE1                   501
#define IDS_EXPOSURE2                   502
#define IDS_EXPOSURE3                   503
#define IDS_EXPOSURETIME1               512
#define IDS_EXPOSURETIME2               513
#define IDS_EXPOSURETIME3               514
#define IDC_BUTTON1                     1000
#define IDC_START                       1000
#define IDC_APPLYCHANGES                1000
#define IDC_MONITOR                     1000
#define IDC_TEST                        1000
#define IDC_BUTTON2                     1001
#define IDC_LOG                         1001
#define IDC_CANCELCHANGES               1001
#define IDC_STACK_DSSLIVE                       1001
#define IDC_BUTTON3                     1002
#define IDC_PAUSE                       1002
#define IDC_PICTURE                     1002
#define IDC_MONITOR2                    1002
#define IDC_REDUCE                      1002
#define IDC_MONITORINGRECT              1003
#define IDC_MONITOREDFOLDER             1004
#define IDC_STOP                        1005
#define IDC_STACKEDIMAGE                1006
#define IDC_LASTIMAGE                   1007
#define IDC_GRAPHS                      1008
#define IDC_IMAGELIST                   1009
#define IDC_LOGLIST                     1010
#define IDC_WARNINGS                    1011
#define IDC_FILENAME_DSSLIVE                    1012
#define IDC_GRAPH                       1014
#define IDC_SCORE                       1015
#define IDC_FWHM                        1016
#define IDC_PROGRESS                    1016
#define IDC_STARS                       1017
#define IDC_DONTSTACK                   1017
#define IDC_DONTSTACK_SCORE             1018
#define IDC_DONTSTACK_STARS             1019
#define IDC_DONTSTACK_FWHM              1020
#define IDC_OFFSET                      1021
#define IDC_STARCOUNT                   1022
#define IDC_ANGLE                       1023
#define IDC_DONTSTACK_OFFSET            1024
#define IDC_SKYBACKGROUND               1024
#define IDC_EDIT4                       1025
#define IDC_MINIMAGES                   1025
#define IDC_DONTSTACK_ANGLE             1026
#define IDC_EDIT5                       1027
#define IDC_DONTSTACK_SKYBACKGROUND     1027
#define IDC_WARN_SOUND                  1028
#define IDC_WARN_FLASH                  1029
#define IDC_WARN_SCORE                  1030
#define IDC_WARN_STARS                  1031
#define IDC_WARN_FWHM                   1032
#define IDC_WARN_OFFSET                 1033
#define IDC_WARN_ANGLE                  1034
#define IDC_SAVESTACKEDIMAGE            1035
#define IDC_EDIT6                       1036
#define IDC_IMAGECOUNT                  1036
#define IDC_WARN_EMAIL                  1037
#define IDC_WARN_FILE                   1038
#define IDC_STACKEDOUTPUTFOLDER         1039
#define IDC_STACKING                    1040
#define IDC_OPTIONS                     1041
#define IDC_STATS                       1042
#define IDC_WARNINGFILEFOLDER           1042
#define IDC_WARN_SKYBACKGROUND          1043
#define IDC_MAX_SKYBACKGROUND           1044
#define IDC_DARKTHEME                   1045
#define IDC_SENDTO                      1048
#define IDC_SMTPSERVER                  1049
#define IDC_ACCOUNT                     1050
#define IDC_OBJECT                      1051
#define IDC_SENDONCE                    1052
#define IDC_EMAIL                       1053
#define IDC_RESETEMAILCOUNT             1054
#define IDC_STARTFROMCURRENTSTACKEDIMAGE 1055
#define IDC_CREATENEWSTACKEDIMAGE       1056
#define IDC_USEPENDINGIMAGES            1057
#define IDC_DROPPENDINGIMAGES           1058
#define IDC_PROCESS_RAW                 1059
#define IDC_PROCESS_FITS                1060
#define IDC_PROCESS_TIFF                1061
#define IDC_PROCESS_OTHERS              1062
#define IDC_FILTERS                     1063
#define IDC_MOVENONSTACKABLE            1064
#define IDC_COPYTOCLIPBOARD             1065
#define IDC_BACKGROUND                  1066
#define IDS_CREATEMASTERDARK            1100
#define IDS_CREATEMASTEROFFSET          1101
#define IDS_ADDOFFSET                   1102
#define IDS_ADDDARK                     1103
#define IDS_SAVINGMASTEROFFSET          1104
#define IDS_SAVINGMASTERDARK            1105
#define IDS_CREATEMASTERFLAT            1106
#define IDS_ADDFLAT                     1107
#define IDS_SAVINGMASTERFLAT            1108
#define IDS_CREATEMASTERDARKFLAT        1109
#define IDS_ADDDARKFLAT                 1110
#define IDS_SAVINGMASTERDARKFLAT        1111
#define IDS_ADDOFFSET2                  1112
#define IDS_REGISTERING                 1120
#define IDS_REGISTERINGPICTURE          1121
#define IDS_REGISTERINGNAME             1122
#define IDS_REGISTERINGNAMEPLUSTARS     1123
#define IDS_COMPUTINGLUMINANCE          1124
#define IDS_LOADRGBPICTURE              1125
#define IDS_LOADGRAYPICTURE             1126
#define IDS_LOADRGBDARK                 1127
#define IDS_LOADGRAYDARK                1128
#define IDS_ADDRGBDARK                  1129
#define IDS_ADDGRAYDARK                 1130
#define IDS_LOADRGBOFFSET               1131
#define IDS_LOADGRAYOFFSET              1132
#define IDS_ADDRGBOFFSET                1133
#define IDS_ADDGRAYOFFSET               1134
#define IDS_COMPUTINGOFFSETS            1135
#define IDS_COMPUTINGSTACKINGINFO       1136
#define IDS_STACKING                    1138
#define IDS_STACKING_PICTURE            1139
#define IDS_LOADRGBLIGHT                1140
#define IDS_LOADGRAYLIGHT               1141
#define IDS_STACKRGBLIGHT               1142
#define IDS_STACKGRAYLIGHT              1143
#define IDS_STACKING_COMPUTINGADJUSTMENT 1144
#define IDS_COMPUTINGADJUSTMENT         1145
#define IDS_STACKING_APPLYINGADJUSTMENT 1146
#define IDS_STACKING_COMPUTEMAXADJUSTMENT 1147
#define IDS_STACKING_APPLYADJUSTMENT    1148
#define IDS_COMPUTINGMEDIANOFFSET       1149
#define IDS_COMPUTINGMEDIANDARK         1150
#define IDS_COMPUTINGMEDIANFLAT         1151
#define IDS_LOADRGBFLAT                 1152
#define IDS_LOADGRAYFLAT                1153
#define IDS_ADDRGBFLAT                  1154
#define IDS_ADDGRAYFLAT                 1155
#define IDS_MEDIANDARKINFO              1156
#define IDS_MEDIANOFFSETINFO            1157
#define IDS_MEDIANFLATINFO              1158
#define IDS_SUBSTRACTINGOFFSET          1159
#define IDS_SUBSTRACTINGDARK            1160
#define IDS_APPLYINGFLAT                1161
#define IDS_NORMALIZINGMASTERFLAT       1162
#define IDC_GAMMA                       1162
#define IDS_COMPUTINGMINLUMINANCE       1163
#define IDS_COMPUTINGENTROPY            1164
#define IDS_COMPUTINGBACKGROUNDCALIBRATION 1165
#define IDS_COMPUTINGDARKOPTIMIZATIONFACTOR 1166
#define IDS_REMOVINGHOTPIXELS           1167
#define IDS_DETECTINGHOTPIXELS1         1168
#define IDS_DETECTINGHOTPIXELS2         1169
#define IDS_COMPUTINGFLATCALIBRATION    1170
#define IDS_APPLYINGFLATCALIBRATION     1171
#define IDS_AHDDEMOSAICING              1172
#define IDS_PROCESSINGIMAGE             1173
#define IDS_APPLYINGCOSMETIC_HOT        1176
#define IDS_APPLYINGCOSMETIC_COLD       1177
#define IDS_CREATINGMEDIANIMAGE         1178
#define IDS_OPTIMIZINGDARKMATCHING      1179
#define IDS_LOADRGBDARKFLAT             1180
#define IDS_LOADGRAYDARKFLAT            1181
#define IDS_COMPUTINGMEDIANDARKFLAT     1182
#define IDS_MEDIANDARKFLATINFO          1183
#define IDS_COMPUTINGCOSMETICSTATS      1185
#define IDS_LOADDSIMAGE                 1200
#define IDS_LOADPICTURE                 1201
#define IDS_SAVEDSIMAGE                 1202
#define IDS_SAVINGDSIMAGE               1203
#define IDS_SAVINGTIFF                  1204
#define IDS_SAVINGPICTURE               1205
#define IDS_SAVEWITHSETTINGSAPPLIED     1206
#define IDS_SAVEWITHSETTINGSEMBEDDED    1207
#define IDS_LOADRGBTIFF                 1208
#define IDS_LOADGRAYTIFF                1209
#define IDS_DEEPSKYSTACKER              1210
#define IDS_SAVINGINTERMEDIATE          1211
#define IDS_SAVINGCALIBRATED            1213
#define IDS_LOADRGBFITS                 1215
#define IDS_LOADGRAYFITS                1216
#define IDS_SAVINGFITS                  1217
#define IDC_4CORNERS                    1258
#define IDS_COMPUTINGMEDIANLIGHT        1300
#define IDS_HAT_LINEAR                  2100
#define IDS_HAT_CUBEROOT                2101
#define IDS_HAT_SQUAREROOT              2102
#define IDS_HAT_LOG                     2103
#define IDS_HAT_LOGLOG                  2104
#define IDS_HAT_LOGSQUAREROOT           2105
#define IDS_HAT_ASINH                   2106
#define IDS_WANTTOCONTINUE              3004
#define IDS_RECAP_AVERAGE               4050
#define IDS_RECAP_MEDIAN                4051
#define IDS_RECAP_MAXIMUM               4052
#define IDS_RECAP_KAPPASIGMA            4053
#define IDS_RECAP_AUTOADAPTIVE          4054
#define IDS_RECAP_ENTROPYAVERAGE        4055
#define IDS_RECAP_MEDIANSIGMACLIP       4056
#define IDS_RECAP_MEGABYTES             4200
#define IDS_RECAP_KILOBYTES             4201
#define IDS_RECAP_GIGABYTES             4202
#define IDS_RECAP_WARNINGDISKSPACE      4250
#define IDS_CAMERA_NOT_SUPPORTED        8001
#define IDS_8BIT_FITS_NODEBAYER         8002
#define IDS_HELPFILE                    20000
#define IDS_SELECTMONITOREDFOLDER       42000
#define IDS_LOG_NEWFILESFOUND           42001
#define IDS_LOG_NEWFILE                 42002
#define IDS_LOG_STARTMONITORING         42003
#define IDS_LOG_PAUSEMONITORING         42004
#define IDS_LOG_STOPMONITORING          42005
#define IDS_LOG_ERRORSTARTMONITORING    42006
#define IDS_NOIMAGELOADED               42007
#define IDS_NOSTACKEDIMAGE              42008
#define IDS_LOG_REGISTERRESULTS         42009
#define IDS_LOG_STARTSTACKING           42010
#define IDS_LOG_STOPSTACKING            42011
#define IDS_LOG_STARTING                42012
#define IDS_LOG_STARTING_1              42013
#define IDS_LOG_STARTING_2              42014
#define IDS_LOG_STARTING_3              42015
#define IDS_LOG_STARTING_4              42016
#define IDS_LOG_STARTING_5              42017
#define IDSTR_LOG_ERRORLOADINGFILE      42018
#define IDS_LOG_ERRORLOADINGFILE        42018
#define IDS_STATUS_LOADED               42019
#define IDS_STATUS_REGISTERED           42020
#define IDS_STATUS_STACKDELAYED         42021
#define IDS_STATUS_NOTSTACKABLE         42022
#define IDS_STATUS_STACKED              42023
#define IDS_LOG_IMAGENOTSTACKABLE1      42024
#define IDS_NOSTACK_SCORE               42025
#define IDS_NOSTACK_STARS               42026
#define IDS_NOSTACK_FWHM                42027
#define IDS_NOSTACK_OFFSET              42028
#define IDS_NOSTACK_ANGLE               42029
#define IDS_NOSTACK_NOTRANSFORMATION    42030
#define IDS_LOG_WARNING                 42031
#define IDS_SELECTWARNINGFOLDER         42032
#define IDS_SELECTSTACKEDFOLDER         42033
#define IDS_SAVINGSTACKEDIMAGE          42034
#define IDS_ERRORSENDINGEMAIL           42035
#define IDS_EMAILSENTOK                 42036
#define IDS_CANTCHANGEMONITOREDFOLDER   42037
#define IDS_SAVESTACKEDIMAGE            42038
#define IDS_NOSTACKEDIMAGEFOLDER        42039
#define IDS_STACKEDIMAGEWILLBESAVED     42040
#define IDS_STACKEDIMAGESAVED           42041
#define IDS_USEEXISTINGIMAGES           42042
#define IDS_ERRORMOVINGFILE             42043
#define IDS_FILEMOVED                   42044
#define IDS_NOSTACK_SKYBACKGROUND       42045

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        140
#define _APS_NEXT_COMMAND_VALUE         32771
#define _APS_NEXT_CONTROL_VALUE         1067
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
